
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Clip-Image-Brightness - Clips the the image brightness.
#   Copyright (C) 2015  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_clip_image_brightness(img, layer, r_clip, g_clip, b_clip):
    ''' This GIMP plugin clips the brightness of an image.

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image.
    r_clip : Clip limit on colour red
    g_clip : Clip limit on colour green
    b_clip : Clip limit on colour blue
    '''

    rmax=r_clip / 100.0
    gmax=g_clip / 100.0
    bmax=b_clip / 100.0
    gimp.context_push()
    mode_subtract = 8
    width = layer.width
    height = layer.height
    pdb.gimp_image_undo_group_start(img)
    new_layer = pdb.gimp_layer_copy(layer, 0)
    img.add_layer(new_layer, -1)
    mask = gimp.Layer(img, "Mask...", layer.width, layer.height, layer.type, layer.opacity, mode_subtract)
    gimp.set_background(rmax, gmax, bmax)
    pdb.gimp_drawable_fill(mask, 1)
    img.add_layer(mask, -1)
    pdb.gimp_image_merge_down(img, mask, 0)
    pdb.gimp_layer_set_mode(img.layers[0], mode_subtract)
    pdb.gimp_image_merge_down(img, img.layers[0], 0)
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_clip_image_brightness",
    "Clip the image brightness",
    "Clip the image at a minimum percentage brightness",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Colour Tools/_Clip image brightness ...",
    "RGB*",
    [
        (PF_SLIDER, "r_clip", "Red limit", 25.0, (0.0, 100.0, 1.0)),
        (PF_SLIDER, "g_clip", "Green limit", 25.0, (0.0, 100.0, 1.0)),
        (PF_SLIDER, "b_clip", "Blue limit", 25.0, (0.0, 100.0, 1.0)),
    ],
    [],
    python_clip_image_brightness,
)

main()
