
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Enhance-Dynamic-Range - Improve contrast in deep sky images
#   Copyright (C) 2017  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *
from array import array

def python_enhance_dynamic_range(img, layer, bright, gwdth, setblk):
    ''' This GIMP plugin enhances dynamic range in a deep sky image (Lodriguss method).

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image.
    bright : The brightness factor (1.0 to 10.0)
    gwdth  : Gaussian blur of mask (1 to 75)
    setblk : Set black point at start (optional)
    '''
    num = len(img.layers)
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    if num == 1:
        if setblk:
            pdb.python_set_black_point(img,layer)
        new_layer_1 = pdb.gimp_layer_copy(layer, 0)
        new_layer_2 = pdb.gimp_layer_copy(layer, 0)
        if bright > 1:
            pdb.python_scale_image_brightness(img,layer,bright)
        img.add_layer(new_layer_1,-1)
        mask=pdb.gimp_layer_create_mask(new_layer_1,0)
        pdb.gimp_layer_add_mask(new_layer_1,mask)
        pdb.gimp_floating_sel_attach(new_layer_2,mask)
        pdb.gimp_floating_sel_anchor(new_layer_2)
        pdb.plug_in_gauss_iir(img ,mask, gwdth, True, True)
    elif num == 2:
        if setblk:
            pdb.python_set_black_point(img,img.layers[0])
            pdb.python_set_black_point(img,img.layers[1])
        if bright > 1:
            pdb.python_scale_image_brightness(img,img.layers[1],bright)
        new_layer = pdb.gimp_layer_copy(img.layers[0], 0)
        mask=pdb.gimp_layer_create_mask(img.layers[0],0)
        pdb.gimp_layer_add_mask(img.layers[0],mask)
        pdb.gimp_floating_sel_attach(new_layer,mask)
        pdb.gimp_floating_sel_anchor(new_layer)
        pdb.plug_in_gauss_iir(img ,mask, gwdth, True, True)
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_enhance_dynamic_range",
    "Enhance the dynamic range in a deep sky image ",
    "Enhance the dynamic range in a deep sky image using Lodriguss method",
    "Bill Smith",
    "Bill Smith",
    "2017",
    "<Image>/Py-Astro/Colour Tools/_Enhance dynamic range...",
    "RGB*",
    [
        (PF_SLIDER, "bright", "Brightness factor", 5.0, (1.0, 10.0, 0.1)),
        (PF_SLIDER, "gwdth", "Gaussian blur (pixels)", 25, (1,75,1)),
        (PF_TOGGLE, "setblk", "Set black point at start", FALSE),
    ],
    [],
    python_enhance_dynamic_range,
)

main()
