
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Enhance-Star-Colours - Boosts the colours of the star images.
#   Copyright (C) 2016  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_enhance_star_colours(img, layer, base):
    ''' This GIMP plugin boosts the colours of the star images.

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image.
    base   : Base level - background noise removal
    '''

    base /= 100.0
    gwdth = 5.0
    intense = 95.0
    mode_subtract = 8
    mode_colour = 13
    width = layer.width
    height = layer.height
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    new_layer = pdb.gimp_layer_copy(layer, 0)
    img.add_layer(new_layer, -1)
    mask = gimp.Layer(img, "Mask...", layer.width, layer.height, layer.type, layer.opacity, mode_subtract)
    gimp.set_background(base, base, base)
    pdb.gimp_drawable_fill(mask, 1)
    img.add_layer(mask, -1)
    pdb.gimp_image_merge_down(img, mask, 0)
    pdb.plug_in_gauss_iir(img , img.layers[0], gwdth, True, True)
    pdb.gimp_hue_saturation(img.layers[0], 0, 0.0, 0.0, intense)
    pdb.gimp_layer_set_mode(img.layers[0], mode_colour)
    pdb.gimp_image_merge_down(img, img.layers[0], 0)
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_enhance_star_colours",
    "Enhance star colours",
    "Enhance star colours",
    "Bill Smith",
    "Bill Smith",
    "2016",
    "<Image>/Py-Astro/Effects/_Enhance star colours ...",
    "RGB*",
    [
        (PF_SLIDER, "base", "Base level", 5.0, (0.0, 25.0, 1.0)),
    ],
    [],
    python_enhance_star_colours,
)

main()
