
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Enhance-Star-Luminance - Boosts the luminance of the star images.
#   Copyright (C) 2016  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_enhance_star_luminance(img, layer, blur):
    ''' This GIMP plugin enhances star luminance.

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image.
    blur   : Gaussian blurring parameter.
    '''

    precision = pdb.gimp_image_get_precision(img)
    bpp = layer.bpp
    if bpp> 8:
        gimp.message("Error - too many bytes per pixel")
        return
    gwdth = float(blur)
    value_mode = 14
    difference_mode = 6
    addition_mode = 7
    desaturate_option = 2
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    new_layer_0 = pdb.gimp_layer_copy(layer, 0)
    img.add_layer(new_layer_0, -1)
    pdb.gimp_drawable_desaturate(new_layer_0, desaturate_option)
    new_layer_1 = pdb.gimp_layer_copy(new_layer_0, 0)
    new_layer_2 = pdb.gimp_layer_copy(new_layer_0, 0)
    img.add_layer(new_layer_1, -1)
    img.add_layer(new_layer_2, -1)
    pdb.plug_in_gauss_iir(img ,new_layer_2, gwdth, True, True)
    pdb.gimp_layer_set_mode(new_layer_2, difference_mode)
    sharpen_mask = pdb.gimp_image_merge_down(img, new_layer_2, 0)
    pdb.gimp_layer_set_mode(sharpen_mask, addition_mode)
    luminance_mask = pdb.gimp_image_merge_down(img, sharpen_mask, 0)
    pdb.gimp_layer_set_mode(luminance_mask, value_mode)
    pdb.gimp_image_merge_down(img, luminance_mask, 0)
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_enhance_star_luminance",
    "Enhance star luminance",
    "Enhance star luminance",
    "Bill Smith",
    "Bill Smith",
    "2018",
    "<Image>/Py-Astro/Effects/_Enhance star luminance ...",
    "RGB*",
    [
        (PF_SLIDER, "blur", "Gaussian blur", 5.0,(1.0, 10.0, 0.1)),
    ],
    [],
    python_enhance_star_luminance)

main()
