
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Enhance-Using SVD layers - Boosts the detail in star images.
#   Copyright (C) 2016  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_enhance_using_svd(img, layer, opac):
    ''' This GIMP plugin enhances an image using Soft light, Value
    (luminance) and Dodge layers (SVD).

    Parameters:
    img     : The currently selected image.
    layer   : The layer of the currently selected image.
    opac    : Opacity of Dodge layer.
    '''

    precision = pdb.gimp_image_get_precision(img)
    bpp = layer.bpp
    if bpp> 8:
        gimp.message("Error - too many bytes per pixel")
        return
    opacity = float(opac)
    value_mode = 14
    dodge_mode = 16
    soft_mode = 19
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    new_layer_0 = pdb.gimp_layer_copy(layer, 0)
    new_layer_1 = pdb.gimp_layer_copy(layer, 0)
    new_layer_2 = pdb.gimp_layer_copy(layer, 0)
    img.add_layer(new_layer_0, -1)
    img.add_layer(new_layer_1, -1)
    img.add_layer(new_layer_2, -1)
    pdb.gimp_layer_set_mode(new_layer_0, soft_mode)
    pdb.gimp_layer_set_mode(new_layer_1, value_mode)
    pdb.gimp_layer_set_mode(new_layer_2, dodge_mode)
    pdb.gimp_layer_set_opacity(new_layer_2, opacity)
    pdb.gimp_image_merge_down(img, new_layer_0, 0)
    pdb.gimp_image_merge_down(img, new_layer_1, 0)
    pdb.gimp_image_merge_down(img, new_layer_2, 0)
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_enhance_using_svd",
    "Enhance using SVD layers",
    "Enhance using Soft light-, Value- and Dodge-mode layers",
    "Bill Smith",
    "Bill Smith",
    "2018",
    "<Image>/Py-Astro/Effects/_Enhance using SVD layers ...",
    "RGB*",
    [
        (PF_SLIDER, "opac", "Dodge layer opacity", 50.0,(1.0, 100.0, 5.0)),
    ],
    [],
    python_enhance_using_svd)

main()
