
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-High-Pass-Filter - sharpens image using high pass filter.
#   Copyright (C) 2016  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *
from array import array

def python_high_pass_filter(img, layer, blur, pack):
    ''' This GIMP plugin removes red sky light pollution.

    Parameters:
    img      : The currently selected image.
    layer    : The layer of the currently selected image.
    blur     : Gaussian blurring parameter
    pack     : Flatten image at end Y/N
    '''

    precision = pdb.gimp_image_get_precision(img)
    bpp = layer.bpp
    if bpp> 8:
        gimp.message("Error - too many bytes per pixel")
        return
    gwdth=float(blur)
    overlay_mode=5
    grain_ext_mode=20
    width = layer.width
    height = layer.height
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    gimp.progress_init("Creating mask ...")
    new_layer_1 = pdb.gimp_layer_copy(layer, 0)
    new_layer_2 = pdb.gimp_layer_copy(layer, 0)
    img.add_layer(new_layer_1, -1)
    img.add_layer(new_layer_2, -1)
    pdb.gimp_drawable_desaturate(new_layer_2, 0)
    pdb.plug_in_gauss_iir(img ,new_layer_2, gwdth, True, True)
    pdb.gimp_layer_set_mode(new_layer_2, grain_ext_mode)
    pdb.gimp_drawable_desaturate(new_layer_1, 0)
    final_mask=pdb.gimp_image_merge_down(img, new_layer_2, 0)
    pdb.gimp_layer_set_mode(final_mask, overlay_mode)
    if pack:
        img.flatten()
    gimp.pdb.gimp_progress_end()
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_high_pass_filter",
    "Sharpen with high pass filter",
    "Sharpen with high pass filter",
    "Bill Smith",
    "Bill Smith",
    "2016",
    "<Image>/Py-Astro/Sharpen/_High pass filter ...",
    "RGB*",
    [
        (PF_SLIDER, "blur", "Gaussian blur", 1.0,(1.0, 10.0, 0.1)),
        (PF_TOGGLE, "pack", "Flatten image", TRUE),
    ],
    [],
    python_high_pass_filter,
)

main()
