#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Image-File-Converter - converts image to selected formal
#   Copyright (C) 2014  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
from gimpfu import *

def python_image_file_converter(img, drawable, image_kind):

    filename=pdb.gimp_image_get_filename(img)
    lst = len(filename)
    if filename[lst-4] == "." :
        shortname = filename[0:lst-4]
        tail=filename[lst-3:lst]
    else :
        shortname = filename[0:lst-5]
        tail=filename[lst-4:lst]
    if tail.lower() == image_kind.lower():
        gimp.message("Error : input and output files have same type")
        return
    try:
        if image_kind.lower() == "png" :
            pdb.file_png_save(img, drawable, shortname + ".PNG", shortname + ".PNG",
                           1, 9, 0, 0, 0, 0, 0)
        elif image_kind.lower() == "jpg" :
            pdb.file_jpeg_save(img, drawable, shortname + ".JPG", shortname + ".JPG",
                           0.9, 0.0, 0, 0, "", 0, 0, 0, 0)
        elif image_kind.lower() == "jpeg" :
            pdb.file_jpeg_save(img, drawable, shortname + ".JPEG", shortname + ".JPEG",
                           0.9, 0.0, 0, 0, "", 0, 0, 0, 0)
        elif image_kind.lower() == "bmp" :
            pdb.file_bmp_save(img, drawable, shortname + ".BMP", shortname + ".BMP")
        elif image_kind.lower() == "gif" :
            pdb.file_gif_save(img, drawable, shortname + ".GIF", shortname + ".GIF",
                           0, 0, 0, 0)
        elif image_kind.lower() == "tif" :
            pdb.file_tiff_save(img, drawable, shortname + ".TIF", shortname + ".TIF",
                           0)
        elif image_kind.lower() == "tiff" :
            pdb.file_tiff_save(img, drawable, shortname + ".TIFF", shortname + ".TIFF",
                           0)
    except Exception as err:
        gimp.message("Error : " + str(err))

register(
    "python_image_file_converter",
    "Convert the image file to chosen format",
    "Convert the image file to JPG, PNG, GIF or BMP",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Misc Tools/_Image file converter ...",
    "RGB*, GRAY*",
    [
        (PF_RADIO, "image_kind", "Image kind:", "jpg",
            (
                ("JPG", "jpg"),
                ("JPEG", "jpeg"),
                ("PNG", "png"),
                 ("BMP", "bmp"),
                ("GIF", "gif"),
                ("TIF", "tif"),
                ("TIFF", "tiff"),
            )
        )
    ],
    [],
    python_image_file_converter,
    )

main()
