#!/usr/bin/env python
# Gimp-Python - allows the writing of Gimp plugins in Python.
#
# Python-Load-Layer-Stack - loads a sequence of images into successive layers.
# Copyright (C) 2014  Bill Smith
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation and/or
#    other materials provided with the distribution.
#    - Neither the name of the author nor the names of its contributors may be used
#    to endorse or promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.

from gimpfu import *

def python_image_list_convert(img, layer, num_files, kind):
    ''' Convert a list of image files.

    Parameters:
    image     : Current image.
    layer     : Layer of the current image.
    num files : Number of sequential files to be converted.
    kind      : Required format of output image files.
    '''
    gimp.context_push()
    types = [".JPG", ".JPEG", ".PNG", ".BMP", ".GIF", ".TIF", ".TIFF"]
    savetail = types[kind]
    loc = [0, 0]
    filenam = pdb.gimp_image_get_filename(img)
    lst = len(filenam)
    if filenam[lst-4] == "." :
        oldtail=filenam[lst-4:lst]
    else :
        oldtail=filenam[lst-5:lst]
    if oldtail.lower() == savetail.lower():
        gimp.message("Error : input and output files have same type")
        return
    (directory, name, tail, loc) = filename_info(filenam)
    saveimg = img
    savelayer = layer

    for i in range(num_files):
        newname = update_name(name, i, loc)
        filenew = directory + newname + tail
        saveimg = None
        try:
            if(tail.lower().endswith(('.jpeg'))):
                saveimg = pdb.file_jpeg_load(filenew, filenew)
            elif(tail.lower().endswith(('.jpg'))):
                saveimg = pdb.file_jpeg_load(filenew, filenew)
            elif(tail.lower().endswith(('.png'))):
                saveimg = pdb.file_png_load(filenew, filenew)
            elif(tail.lower().endswith(('.tif'))):
                saveimg = pdb.file_tiff_load(filenew, filenew)
            elif(tail.lower().endswith(('.tiff'))):
                saveimg = pdb.file_tiff_load(filenew, filenew)
            elif(tail.lower().endswith(('.bmp'))):
                saveimg = pdb.file_bmp_load(filenew, filenew)
            elif(tail.lower().endswith(('.gif'))):
                saveimg = pdb.file_gif_load(filenew, filenew)
        except Exception as err:
            gimp.message("Error loading file: " + newname + tail + "Code: " + str(err))
            saveimg = None

        if (saveimg is None):
            gimp.message("The image file " + newname + tail + " could not be opened.")
        else:
            savelayer = saveimg.layers[0]
            try:
                savename = update_name(name, i, loc)
                filesave = directory + savename + savetail
                if(kind == 0):
                    pdb.file_jpeg_save(saveimg, savelayer, filesave, filesave,
                                   0.9, 0.0, 0, 0, "", 0, 0, 0, 0)
                elif(kind == 1):
                    pdb.file_jpeg_save(saveimg, savelayer, filesave, filesave,
                                   0.9, 0.0, 0, 0, "", 0, 0, 0, 0)
                elif(kind == 2):
                    pdb.file_png_save(saveimg, savelayer, filesave, filesave,
                                   1, 9, 0, 0)
                elif(kind == 3):
                    pdb.file_bmp_save(saveimg, savelayer, filesave, filesave)
                elif(kind == 4):
                    pdb.file_gif_save(saveimg, savelayer, filesave, filesave,
                               0, 0, 0, 0)
                elif(kind == 5):
                    pdb.file_tiff_save(saveimg, savelayer, filesave, filesave, 0)
                elif(kind == 6):
                    pdb.file_tiff_save(saveimg, savelayer, filesave, filesave, 0)
            except Exception as err:
                gimp.message("Error saving file " +savename + savetail + "(Code : " + str(err) + ")")

    gimp.context_pop()

def filename_info(filenam):

    e = 0
    loc = [-1, -1]
    i = len(filenam)
    tail = ''
    name = ''
    directory = ''
    flag = True
    while(flag):
        i -= 1
        if filenam[i] == '\x2E':
            tail = filenam[i:]
            e = i
        elif ord(filenam[i]) >= 48 and ord(filenam[i]) <= 57:
            if loc[1] < 0:
                loc[1] = i + 1
                loc[0] = i
            elif loc[0] == i + 1:
                loc[0] = i
        elif filenam[i] == '\x2F' or filenam[i] == '\x5C':
            directory = filenam[:i + 1]
            name = filenam[i + 1:e]
            flag = False
        if i == 0: flag = False
    d = len(directory)
    loc[0] -= d
    loc[1] -= d
    return (directory, name, tail, loc)


def update_name(name, n, loc):
    num = int(name[loc[0]:loc[1]]) + n
    dec = str(num)
    for i in range(loc[1] - loc[0] - len(dec)):
        dec = '0' + dec
    return (name[:loc[0]] + dec + name[loc[1]:])

register(
    "python_image_list_convert",
    "Converts a list of image files",
    "Converts a list of image files",
    "Bill Smith",
    "Bill Smith",
    "2016",
    "<Image>/Py-Astro/Misc Tools/Image list converter ...",
    "RGB*",
    [
        (PF_INT, "num_files", "Number of files to convert", 1),
        (PF_OPTION, "kind"  ,("Image Type: "), 0 ,["JPG", "JPEG", "PNG", "BMP", "GIF", "TIF", "TIFF"]),
    ],
    [],
    python_image_list_convert)

main()

