#!/usr/bin/env python
# Gimp-Python - allows the writing of Gimp plugins in Python.
#
# Python-Layers-Divide-Flat - Divides the image stack by a flat image.
# Copyright (C) 2014  Bill Smith
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation and/or
#    other materials provided with the distribution.
#    - Neither the name of the author nor the names of its contributors may be used
#    to endorse or promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.

from gimpfu import *

def python_layer_divide_flat(img, layer, flat):
    '''Divide image layers by a flat image.

    Parameters:
    image     : Current image - home of the stacked images
    layer     : Layer of the current image (ignored).
    flat      : File name of flat image
    '''
    precision = pdb.gimp_image_get_precision(img)
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    gimp.progress_init("Loading flat image file ...")
    try:
        if(flat.lower().endswith(('.jpeg'))):
            fimg = pdb.file_jpeg_load(flat, flat)
        elif(flat.lower().endswith(('.jpg'))):
            fimg = pdb.file_jpeg_load(flat, flat)
        elif(flat.lower().endswith(('.png'))):
            fimg = pdb.file_png_load(flat, flat)
        elif(flat.lower().endswith(('.tif'))):
            fimg = pdb.file_tiff_load(flat, flat)
        elif(flat.lower().endswith(('.tiff'))):
            fimg = pdb.file_tiff_load(flat, flat)
        elif(flat.lower().endswith(('.bmp'))):
            fimg = pdb.file_bmp_load(flat, flat)
        elif(flat.lower().endswith(('.gif'))):
            fimg = pdb.file_gif_load(flat, flat)
    except Exception as err:
        gimp.message("Error loading flat file: " + str(err))
        gimp.pdb.gimp_progress_end()
        pdb.gimp_image_undo_group_end(img)
        gimp.context_pop()
        return
    gimp.pdb.gimp_progress_end()

    mode = 15
    width = fimg.layers[0].width
    height = fimg.layers[0].height
    bpp = fimg.layers[0].bpp
    if bpp != layer.bpp or width != layer.width or height != layer.height:
        gimp.message("Error - flat image and stack images not compatible")
    else:
        num = len(img.layers)
        gimp.progress_init("Dividing by flat image ...")
        pdb.gimp_layer_set_mode(fimg.layers[0], mode)
        pdb.gimp_edit_copy(fimg.layers[0])
        for k in range(num):
            if(pdb.gimp_item_get_visible(img.layers[num-k-1]) == True):
                pdb.gimp_edit_paste(img.layers[num-k-1], True)
                pdb.gimp_layer_set_mode(img.layers[num-k-1], mode)
                pdb.gimp_floating_sel_anchor(img.layers[num-k-1])
            gimp.progress_update(float(k+1) / num)
        gimp.pdb.gimp_progress_end()
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_layer_divide_flat",
    "Divide image layers by a flat image",
    "Divide multi-layer image stack by a flat image",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Layer Tools/_Divide layers by flat ...",
    "RGB*",
    [
        (PF_FILE, "file", "Select flat image file:", ""),
    ],
    [],
    python_layer_divide_flat,
)

main()
