#!/usr/bin/env python
# Gimp-Python - allows the writing of Gimp plugins in Python.
#
# Python-Layer-Subtract-Dark - subtracts a dark image from a stack of layers.
# Copyright (C) 2014  Bill Smith
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation and/or
#    other materials provided with the distribution.
#    - Neither the name of the author nor the names of its contributors may be used
#    to endorse or promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.

from gimpfu import *

def python_layer_subtract_dark2(img, layer, dark):
    '''Subtract a dark layer fron a layer stack.

    Parameters:
    image     : Current image - home of the stacked images
    layer     : Layer of the current image (ignored).
    dark      : File name of dark image
    '''
    precision = pdb.gimp_image_get_precision(img)
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    gimp.progress_init("Loading dark image file ...")
    try:
        if(dark.lower().endswith(('.jpeg'))):
            dimg = pdb.file_jpeg_load(dark, dark)
        elif(dark.lower().endswith(('.jpg'))):
            dimg = pdb.file_jpeg_load(dark, dark)
        elif(dark.lower().endswith(('.png'))):
            dimg = pdb.file_png_load(dark, dark)
        elif(dark.lower().endswith(('.tif'))):
            dimg = pdb.file_tiff_load(dark, dark)
        elif(dark.lower().endswith(('.tiff'))):
            dimg = pdb.file_tiff_load(dark, dark)
        elif(dark.lower().endswith(('.bmp'))):
            dimg = pdb.file_bmp_load(dark, dark)
        elif(dark.lower().endswith(('.gif'))):
            dimg = pdb.file_gif_load(dark, dark)
    except Exception as err:
        gimp.message("Error loading dark file files: " + str(err))
        gimp.pdb.gimp_progress_end()
        pdb.gimp_image_undo_group_end(img)
        gimp.context_pop()
        return
    gimp.pdb.gimp_progress_end()

    mode = 8
    width = dimg.layers[0].width
    height = dimg.layers[0].height
    bpp = dimg.layers[0].bpp
    if bpp != layer.bpp or width != layer.width or height != layer.height:
        gimp.message("Error - dark image and stack images not compatible")
    else:
        num = len(img.layers)
        gimp.progress_init("Subtracting dark image ...")
        pdb.gimp_layer_set_mode(dimg.layers[0], mode)
        pdb.gimp_edit_copy(dimg.layers[0])
        for k in range(num):
            if(pdb.gimp_item_get_visible(img.layers[num-k-1]) == True):
                pdb.gimp_edit_paste(img.layers[num-k-1], True)
                pdb.gimp_layer_set_mode(img.layers[num-k-1], mode)
                pdb.gimp_floating_sel_anchor(img.layers[num-k-1])
            gimp.progress_update(float(k+1) / num)
        gimp.pdb.gimp_progress_end()
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_layer_subtract_dark2",
    "Subtract a dark image from a stack of images",
    "Subtract a dark image from a stack of images in successive layers",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Layer Tools/_Subtract dark from layers ...",
    "RGB*",
    [
        (PF_FILE, "file", "Select dark image file:", ""),
    ],
    [],
    python_layer_subtract_dark2,
)

main()
