#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python_Merge_Channels - merges separated colour channels in an image
#   Copyright (C) 2015 Bill Smith
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation and/or
#    other materials provided with the distribution.
#    - Neither the name of the author nor the names of its contributors may be used
#    to endorse or promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from gimpfu import *

def python_merge_channels(img, layer) :
    ''' Merges separated colour channels in image.

    Parameters:
    img   : image The current image.
    layer : Current layer (irrelevant)
    '''

    gimp.progress_init("Merging channels .... ")
    pdb.gimp_image_undo_group_start(img)
    if len(img.layers) == 3 :
        pdb.gimp_layer_set_mode(img.layers[0], 7)
        pdb.gimp_layer_set_mode(img.layers[1], 7)
        pdb.gimp_layer_set_mode(img.layers[2], 0)
        img.flatten()
        pdb.gimp_item_set_name(img.layers[0],"RGB image")
    pdb.gimp_image_undo_group_end(img)
    gimp.pdb.gimp_progress_end()

register(
    "python_merge_channels",
    "Merge colour channels",
    "Merge colour channels by addition",
    "Bill Smith",
    "Bill Smith",
    "2015",
    "<Image>/Py-Astro/Colour Tools/_Merge colour channels",
    "RGB, RGB*",
    [],
    [],
    python_merge_channels
)

main()
