#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python_Merge_Layers - merge down all layers in the image with the
#   appropriate opacity
#   Copyright (C) 2014 Bill Smith
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation and/or
#    other materials provided with the distribution.
#    - Neither the name of the author nor the names of its contributors may be used
#    to endorse or promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from gimpfu import *

def python_merge_layers(img, layer) :
    ''' Merges all layers in image with appropriate opacity.

    Parameters:
    img   : image The current image.
    layer : Current layer (irrelevant)
    '''
    pdb.gimp_image_undo_group_start(img)
    num = len(img.layers)
    n = 0
    # count visible layers
    for i in range(num):
        if (pdb.gimp_item_get_visible(img.layers[i]) == True):
            n += 1
    #  visible layers
    k=0
    for i in range(num):
        if (pdb.gimp_item_get_visible(img.layers[i]) == True):
            blend = int(1000 / (n - k)) / 10.0
            pdb.gimp_layer_set_opacity(img.layers[i], blend)
            pdb.gimp_layer_set_mode(img.layers[i], 0)
            k += 1
    img.flatten()
    pdb.gimp_item_set_name(img.layers[0],"Merged image")
    pdb.gimp_image_undo_group_end(img)

register(
    "python_merge_layers",
    "Merge all layers",
    "Merge all layers in image with appropriate opacity",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Layer Tools/_Merge all layers",
    "RGB, RGB*",
    [],
    [],
    python_merge_layers)

main()
