
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Image-Peek - Peeks into image pixel.
#   Copyright (C) 2015  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *
from array import array

def python_pixel_peek(img, layer, xpos, ypos):
    ''' This GIMP plugin peeks into the contents of a pixel.

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image.
    xpos   : X-coordinate of chosen pixel.
    ypos   : Y-coordinate of chosen pixel.
    '''
    width = layer.width
    height = layer.height
    precision = pdb.gimp_image_get_precision(img)
    bpp = layer.bpp
    home_rgn = layer.get_pixel_rgn(0, 0, width, height, False, False)
    home_pixels = array("B", home_rgn[0:width, 0:height])
    p = (xpos + width * ypos) * bpp
    gimp.message("Bpp : "+str(bpp)+"   Bytes : "+str(home_pixels[p:p + bpp]))
register(
    "python_pixel_peek",
    "Peek into image pixel",
    "Peek into image pixel",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Misc Tools/_Pixel peek...",
    "RGB*, GRAY*",
    [
        (PF_INT, "xpos", "Pixel x-coordinate", 0),
        (PF_INT, "xyos", "Pixel y-coordinate", 0)
    ],
    [],
    python_pixel_peek,
    )

main()
