
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Purge-Red-Sky - removes red sky light pollution.
#   Copyright (C) 2016  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_purge_red_sky(img, layer, clip, blur, blend, pack):
    ''' This GIMP plugin removes red sky light pollution.

    Parameters:
    img      : The currently selected image.
    layer    : The layer of the currently selected image.
    clip     : Clip limit on sky colour
    blur     : Gaussian blurring parameter
    blend    : Strength of red sky correction
    pack     : Flatten image at end Y/N
    '''

    cmax=clip / 100.0
    gwdth=float(blur)
    opacity=float(blend)
    mode_difference = 6
    mode_subtract = 8
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    one_layer = pdb.gimp_layer_copy(layer, 0)
    two_layer = pdb.gimp_layer_copy(layer, 0)
    img.add_layer(one_layer, -1)
    img.add_layer(two_layer, -1)
    mask = gimp.Layer(img, "Mask ...", layer.width, layer.height, layer.type, layer.opacity, mode_subtract)
    gimp.set_background(cmax, cmax, cmax)
    pdb.gimp_drawable_fill(mask, 1)
    img.add_layer(mask, -1)
    pdb.gimp_image_merge_down(img, mask, 0)
    pdb.gimp_layer_set_mode(img.layers[0], mode_subtract)
    pdb.gimp_image_merge_down(img, img.layers[0], 0)
    pdb.plug_in_gauss_iir(img ,img.layers[0], gwdth, True, True)
    pdb.gimp_layer_set_opacity(img.layers[0], opacity)
    pdb.gimp_layer_set_mode(img.layers[0], mode_difference)
    if pack:
        pdb.gimp_image_merge_down(img, img.layers[0], 0)
    gimp.pdb.gimp_progress_end()
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_purge_red_sky",
    "Remove red sky from image",
    "Remove red sky from image and correct vignetting",
    "Bill Smith",
    "Bill Smith",
    "2016",
    "<Image>/Py-Astro/Colour Tools/_Purge red sky ...",
    "RGB*",
    [
        (PF_SLIDER, "clip", "Red sky level", 25.0, (1.0, 100.0, 1.0)),
        (PF_SLIDER, "blur", "Gaussian blur", 75.0,(50.0, 100.0, 1.0)),
        (PF_SLIDER, "blend", "Strength", 75.0, (1.0, 100.0, 1.0)),
        (PF_TOGGLE, "pack", "Flatten image", TRUE),
    ],
    [],
    python_purge_red_sky,
)

main()
