#!/usr/bin/env python
# Gimp-Python - allows the writing of Gimp plugins in Python.
#
# Python-Save-Layer-Stack - saves image layers as a sequence of images files.
# Copyright (C) 2014  Bill Smith
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation and/or
#    other materials provided with the distribution.
#    - Neither the name of the author nor the names of its contributors may be used
#    to endorse or promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.

from gimpfu import *

def python_save_layer_stack(img, layer, kind):
    ''' Load a sequence of image files to make a layer stack.

    Parameters:
    image     : Current image.
    layer     : Layer of the current image.
    kind      : Type of image file to be saved
    '''
    gimp.progress_init("Saving image layers ...")
    types = [".JPG", ".JPEG", ".PNG", ".BMP", ".GIF", ".TIF", ".TIFF"]
    tail = types[kind]
    loc = [0, 0]
    filenam = pdb.gimp_image_get_filename(img)
    (directory, name, loc) = filename_info(filenam)
    filenam2 = directory + "STACK00" + tail
    (directory, name, loc) = filename_info(filenam2)
    num = len(img.layers)
    gimp.context_push()

    try:
        for i in range(num):
            layer = img.layers[num - i - 1]
            newnam = update_name(name, i, loc)
            filenew = directory + newnam + tail

            if(kind == 0):
                pdb.file_jpeg_save(img, layer,filenew, filenew,
                               0.9, 0.0, 0, 0, "", 0, 0, 0, 0)
            elif(kind == 1):
                pdb.file_jpeg_save(img, layer, filenew, filenew,
                               0.9, 0.0, 0, 0, "", 0, 0, 0, 0)
            elif(kind == 2):
                pdb.file_png_save(img, layer, filenew, filenew,
                               1, 9, 0, 0, 0, 0, 0)
            elif(kind == 3):
                pdb.file_bmp_save(img, layer, filenew, filenew)
            elif(kind == 4):
                pdb.file_gif_save(img, layer, filenew, filenew,
                           0, 0, 0, 0)
            elif(kind == 5):
                pdb.file_tiff_save(img, layer, filenew, filenew,
                           0)
            elif(kind == 6):
                pdb.file_tiff_save(img, layer, filenew, filenew,
                           0)

    except Exception as err:
            gimp.message("Error processing files: " + str(err))

    gimp.context_pop()

def filename_info(filenam):

    e = 0
    loc = [-1, -1]
    i = len(filenam)
    name = ''
    directory = ''
    flag = True
    while(flag):
        i -= 1
        if filenam[i] == '\x2E':
            e = i
        elif ord(filenam[i]) >= 48 and ord(filenam[i]) <= 57:
            if loc[1] < 0:
                loc[1] = i + 1
                loc[0] = i
            elif loc[0] == i + 1:
                loc[0] = i
        elif filenam[i] == '\x2F' or filenam[i] == '\x5C':
            directory = filenam[:i + 1]
            name = filenam[i + 1:e]
            flag = False
        if i == 0: flag = False
    d = len(directory)
    loc[0] -= d
    loc[1] -= d
    return (directory, name, loc)

def update_name(name, n, loc):
    num = int(name[loc[0]:loc[1]]) + n
    dec = str(num)
    for i in range(loc[1] - loc[0] - len(dec)):
        dec = '0' + dec
    return (name[:loc[0]] + dec + name[loc[1]:])

register(
    "python_save_layer_stack",
    "Save a stack of images",
    "Save each image layer as required image file type",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Layer Tools/Save all layers ...",
    "RGB*",
    [
        (PF_OPTION, "kind"  ,("Image Type: "), 0 ,["JPG", "JPEG", "PNG", "BMP", "GIF", "TIF", "TIFF"]),
    ],
    [],
    python_save_layer_stack)

main()
