
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Scale-Image-Brightness - Multiplies the image brightness.
#   Copyright (C) 2015  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_scale_image_brightness(img, layer, bright):
    ''' This GIMP plugin scales the brightness of an image layer.

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image.
    bright : The brightness factor (1.0 to 5.0)
    '''
    basec = 1.0 / bright
    gimp.context_push()
    mode_divide = 15
    pdb.gimp_image_undo_group_start(img)
    newlay = gimp.Layer(img, "Mask...", layer.width, layer.height, layer.type, layer.opacity, mode_divide)
    gimp.set_background(basec, basec, basec)
    img.add_layer(newlay, -1)
    pdb.gimp_drawable_fill(newlay, 1)
    pdb.gimp_image_merge_down(img, newlay, 0)
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()


register(
    "python_scale_image_brightness",
    "Scale the image brightness",
    "Scale the image brightness by factor 1.0 to 5.0",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Colour Tools/_Scale image brightness ...",
    "RGB*",
    [
        (PF_SLIDER, "bright", "Brightness factor", 1.0, (1.0, 5.0, 0.1)),
    ],
    [],
    python_scale_image_brightness,
)

main()
