
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Scale-Image-Brightness - Multiplies the brightness of all layers.
#   Copyright (C) 2015  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_scale_layers_brightness(img, layer, bright):
    ''' This GIMP plugin scales the brightness of all layers.

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image (ignore).
    bright : The brightness factor (1.0 to 5.0).
    '''

    basec = 1.0 / bright
    mode_divide = 15
    num = len(img.layers)
    progress = 0.0
    max_progress = float(num)
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    gimp.set_background(basec, basec, basec)
    gimp.progress_init("Scaling all layers ...")
    for k in range(num):
        layer = img.layers[num - k -1 ]
        newlay = gimp.Layer(img, "Mask...", layer.width, layer.height, layer.type, layer.opacity, mode_divide)
        pdb.gimp_drawable_fill(newlay, 1)
        img.add_layer(newlay, num - k - 1)
        pdb.gimp_image_merge_down(img, newlay, 0)
        progress += 1.0
        gimp.progress_update(progress / max_progress)
    gimp.pdb.gimp_progress_end()
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_scale_layers_brightness",
    "Scale brightness of all layers",
    "Scale brightness of all layers by factor 1.0 to 5.0",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Layer Tools/_Scale brightness of all layers ...",
    "RGB*",
    [
        (PF_SLIDER, "bright", "Brightness factor", 1.0, (1.0, 5.0, 0.1)),
    ],
    [],
    python_scale_layers_brightness,
)

main()
