#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python_Set_Layer_Modes - set mode of all layers in the image except
#   for the bottom layer
#   Copyright (C) 2014 Bill Smith
#
# Redistribution and use in source and binary forms, with or without modification,
# are permitted provided that the following conditions are met:
#
#    - Redistributions of source code must retain the above copyright notice, this
#    list of conditions and the following disclaimer.
#    - Redistributions in binary form must reproduce the above copyright notice,
#    this list of conditions and the following disclaimer in the documentation and/or
#    other materials provided with the distribution.
#    - Neither the name of the author nor the names of its contributors may be used
#    to endorse or promote products derived from this software without specific prior
#    written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
# DAMAGE.
#

from gimpfu import *

def python_set_layer_modes(img, layer, mode) :
    ''' Sets the mode of all layers except bottom layer.

    Parameters:
    img   : The current image.
    layer : The current layer (irrelevant)
    mode  : The required new mode
    '''
    key = [0, 1,10, 4,16, 7, 9, 3,17, 5,19,18, 6, 8,20,21,15,11,12,13,14]
    pdb.gimp_image_undo_group_start(img)
    num = len(img.layers)
    pdb.gimp_layer_set_mode(img.layers[num-1], 0)
    for i in range(num - 1):
        pdb.gimp_layer_set_mode(img.layers[i], key[mode])
    pdb.gimp_image_undo_group_end(img)

register(
    "python_set_layer_modes",
    "Set mode of all layers",
    "Set mode of all layers (and bottom layer to Normal)",
    "Bill Smith",
    "Bill Smith",
    "2014",
    "<Image>/Py-Astro/Layer Tools/_Set all layer modes ...",
    "RGB, RGB*",
    [
        (PF_OPTION, "mode"  ,("Layer mode: "), 0 ,["Normal", "Dissolve", "Lighten only",
        "Screen", "Dodge", "Addition", "Darken only", "Multiply", "Burn", "Overlay",
        "Soft light", "Hard light", "Difference", "Subtract", "Grain extract",
        "Grain merge", "Divide", "Hue", "Saturation", "Color", "Value" ]),
    ],
    [],
    python_set_layer_modes)

main()
