
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Undercut-Image-Brightness - Undercuts the the image brightness.
#   Copyright (C) 2015  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *

def python_undercut_image_brightness(img, layer, r_cut, g_cut, b_cut):
    ''' This GIMP plugin undercuts the brightness of an image.

    Parameters:
    img    : The currently selected image.
    layer  : The layer of the currently selected image.
    r_cut  : Cut limit on colour red
    g_cut  : Cut limit on colour green
    b_cut  : Cut limit on colour blue
    '''

    rmin = r_cut / 100.0
    gmin = g_cut / 100.0
    bmin = b_cut / 100.0
    gimp.context_push()
    mode_subtract = 8
    pdb.gimp_image_undo_group_start(img)
    newlay = gimp.Layer(img, "Mask...", layer.width, layer.height, layer.type, layer.opacity, mode_subtract)
    gimp.set_background(rmin, gmin, bmin)
    pdb.gimp_drawable_fill(newlay, 1)
    img.add_layer(newlay, -1)
    pdb.gimp_image_merge_down(img, newlay, 0)
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_undercut_image_brightness",
    "Undercut the image brightness",
    "Undercut the image at by a maximum percentage brightness",
    "Bill Smith",
    "Bill Smith",
    "2016",
    "<Image>/Py-Astro/Colour Tools/_Undercut image brightness ...",
    "RGB*",
    [
        (PF_SLIDER, "r_cut", "Red limit", 25.0, (0.0, 100.0, 1.0)),
        (PF_SLIDER, "g_cut", "Green limit", 25.0, (0.0, 100.0, 1.0)),
        (PF_SLIDER, "b_cut", "Blue limit", 25.0, (0.0, 100.0, 1.0)),
    ],
    [],
    python_undercut_image_brightness,
)

main()
