
#!/usr/bin/env python
#   Gimp-Python - allows the writing of Gimp plugins in Python.
#
#   Python-Unsharp-Mask - sharpens image using unsharp mask method.
#   Copyright (C) 2016  Bill Smith
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

from gimpfu import *
from array import array

def python_unsharp_mask(img, layer, blur, strength):
    ''' This GIMP plugin is a simple unsharp mask.

    Parameters:
    img      : The currently selected image.
    layer    : The layer of the currently selected image.
    blur     : Gaussian blurring parameter
    strength : Strength of sharpening effect (%)
    '''

    #precision = pdb.gimp_image_get_precision(img)
    bpp = layer.bpp
    if bpp> 8:
        gimp.message("Error - too many bytes per pixel")
        return
    gwdth=float(blur)
    difference_mode=6
    subtraction_mode=8
    width = layer.width
    height = layer.height
    gimp.context_push()
    pdb.gimp_image_undo_group_start(img)
    gimp.progress_init("Creating mask ...")
    new_layer_1 = pdb.gimp_layer_copy(layer, 0)
    new_layer_2 = pdb.gimp_layer_copy(layer, 0)
    img.add_layer(new_layer_1, -1)
    img.add_layer(new_layer_2, -1)
    pdb.plug_in_gauss_iir(img ,new_layer_2, gwdth, True, True)
    pdb.gimp_layer_set_mode(new_layer_2, difference_mode)
    final_mask = pdb.gimp_image_merge_down(img, new_layer_2, 0)
    pdb.gimp_layer_set_opacity(final_mask, strength)
    pdb.gimp_layer_set_mode(final_mask, subtraction_mode)
    pdb.gimp_image_merge_down(img, final_mask, 0)

    gimp.pdb.gimp_progress_end()
    pdb.gimp_image_undo_group_end(img)
    gimp.context_pop()

register(
    "python_unsharp_mask",
    "Sharpen with unsharp mask",
    "Sharpen with (basic) unsharp mask",
    "Bill Smith",
    "Bill Smith",
    "2016",
    "<Image>/Py-Astro/Sharpen/_Unsharp mask ...",
    "RGB*",
    [
        (PF_SLIDER, "blur", "Gaussian blur", 4.0,(1.0, 10.0, 0.1)),
        (PF_SLIDER, "strength", "Strength", 50.0,(1.0, 100.0, 1.0)),
    ],
    [],
    python_unsharp_mask,
)

main()
